9becedc43e4d

I can't spell
[view raw] [browse files]
author Steve Losh <steve@stevelosh.com>
date Tue, 10 May 2016 00:05:11 +0000
parents 6392237bf417
children b073c3d4a7a9
branches/tags (none)
files src/wam/constants.lisp src/wam/types.lisp src/wam/vm.lisp src/wam/wam.lisp

Changes

--- a/src/wam/types.lisp	Tue May 10 00:00:53 2016 +0000
+++ b/src/wam/types.lisp	Tue May 10 00:05:11 2016 +0000
@@ -40,7 +40,7 @@
   `(unsigned-byte ,+code-word-size+))
 
 (deftype code-index ()
-  ;; either an address or the sentinal
+  ;; either an address or the sentinel
   `(integer 0 ,(1- +code-limit+)))
 
 
--- a/src/wam/vm.lisp	Tue May 10 00:00:53 2016 +0000
+++ b/src/wam/vm.lisp	Tue May 10 00:05:11 2016 +0000
@@ -530,7 +530,7 @@
                    `(instruction-call wam ,inst code pc ,args)))
         (loop
           :while (and (not (wam-fail wam)) ; failure
-                      (not (= pc +code-sentinal+))) ; finished
+                      (not (= pc +code-sentinel+))) ; finished
           :for opcode = (aref code pc)
           :do
           (block op
@@ -604,7 +604,7 @@
     (wam-reset! wam)
     (wam-load-query-code! wam code)
     (setf (wam-program-counter wam) 0
-          (wam-continuation-pointer wam) +code-sentinal+)
+          (wam-continuation-pointer wam) +code-sentinel+)
     (when *step*
       (format *debug-io* "Built query code:~%")
       (dump-code-store wam code))
--- a/src/wam/wam.lisp	Tue May 10 00:00:53 2016 +0000
+++ b/src/wam/wam.lisp	Tue May 10 00:05:11 2016 +0000
@@ -119,7 +119,7 @@
 ;;; and stack have been accounted for.  Because the store is adjustable and the
 ;;; heap lives at the end of it, the heap can grow if necessary.
 ;;;
-;;; We reserve the first address in the heap as a sentinal, as an "unset" value
+;;; We reserve the first address in the heap as a sentinel, as an "unset" value
 ;;; for various pointers into the heap.
 
 (defun* wam-heap-pointer-unset-p ((wam wam) (address heap-index))
@@ -201,7 +201,7 @@
 ;;; The stack is stored as a fixed-length hunk of the main WAM store array,
 ;;; between the local register and the heap, with small glitch: we reserve the
 ;;; first word of the stack (address `+stack-start`) to mean "uninitialized", so
-;;; we have a nice sentinal value for the various pointers into the stack.
+;;; we have a nice sentinel value for the various pointers into the stack.
 
 (declaim (inline wam-stack-word))
--- a/src/wam/constants.lisp	Tue May 10 00:00:53 2016 +0000
+++ b/src/wam/constants.lisp	Tue May 10 00:05:11 2016 +0000
@@ -19,9 +19,9 @@
 (define-constant +code-limit+ (expt 2 +code-word-size+)
   :documentation "Maximum size of the WAM code store.")
 
-(define-constant +code-sentinal+ (1- +code-limit+)
-  ; TODO: Should this sentinal value be 0 like everything else?
-  :documentation "Sentinal value used in the PC and CP.")
+(define-constant +code-sentinel+ (1- +code-limit+)
+  ; TODO: Should this sentinel value be 0 like everything else?
+  :documentation "Sentinel value used in the PC and CP.")
 
 
 (define-constant +tag-null+      #b00